@@ -15,9 +15,9 @@ from .__containers import (
     SetContaining,
 )
 from .__float_approx import FloatApprox
-from .__equals import Is
-from .__logicals import And, Not, Or, Xor
-from .__str_match import StringMatchingRegex
+from .__equals import Equals, Is
+from .logicals import And, Not, Or, Xor
+from .__str_match import StringMatchingRegex, StringContaining
 
 
 __all__ = [
@@ -27,12 +27,14 @@ __all__ = [
     'DictContainingKeys',
     'DictContainingValues',
     'DictContainingItems',
+    'Equals',
     'FloatApprox',
     'Is',
     'ListContaining',
     'Not',
     'Or',
     'SetContaining',
+    'StringContaining',
     'StringMatchingRegex',
     'Xor',
 ]
